/***************************************************************************
                          puQT.h.h  -  description
                             -------------------
    begin                : Mit Apr 08 13:11:41 CEST 2004
    copyright            : (C) 2004 by Harald Krippel
    email                : harald@hte-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#ifndef _PU_QT_H_
#define _PU_QT_H_

#ifndef PU_USE_NONE
# define PU_USE_NONE
#endif

#include <plib/pu.h>
#include "main.h"

inline int puGetWindowQT ()
{
    return 0 ;
}

inline void puGetWindowSizeQT ( int *width, int *height )
{
    
    *width  = g_window_w;
    *height = g_window_h;
}

inline void puInitQT ()
{
    puSetWindowFuncs ( puGetWindowQT,
		       NULL,
		       puGetWindowSizeQT,
		       NULL ) ;
    puRealInit () ;
}


#endif
